# PPOCR-ONNX


## 简介

利用 onnxruntime 及 PaddleOCR 提供的模型, 对图片中的文字进行检测与识别.

### 使用模型

 - 文字检测: `ch_PP-OCRv2_det_infer`
 - 方向分类: `cls mobile v2`
 - 文字识别: `rec mobile v2`

## 参考

 - [PaddleOCR](https://github.com/PaddlePaddle/PaddleOCR)
 - [手把手教你使用ONNXRunTime部署PP-OCR](https://aistudio.baidu.com/aistudio/projectdetail/1479970)
 - `ch_PP-OCRv2_det_infer` 模型来自 [RapidAI/RapidOCR](https://github.com/RapidAI/RapidOCR)
